@@ -28,7 +28,8 @@ pub struct Module<'a> {
         feature = "serde",
         serde(
             default = "HashMap::default",
-            deserialize_with = "deser_helpers::nullable_submodules"
+            deserialize_with = "deser_helpers::nullable_submodules",
+            serialize_with = "deser_helpers::ser_submodules",
         )
     )]
     pub submodules: HashMap<CaoIdentifier<'a>, Module<'a>>,
@@ -36,7 +37,8 @@ pub struct Module<'a> {
         feature = "serde",
         serde(
             default = "HashMap::default",
-            deserialize_with = "deser_helpers::nullable_lanes"
+            deserialize_with = "deser_helpers::nullable_lanes",
+            serialize_with = "deser_helpers::ser_lane",
         )
     )]
     pub lanes: HashMap<CaoIdentifier<'a>, Lane>,
@@ -45,7 +47,21 @@ pub struct Module<'a> {
 #[cfg(feature = "serde")]
 mod deser_helpers {
     use super::*;
-    use serde::{Deserialize, Deserializer};
+    use serde::{Deserialize, Deserializer, Serializer};
+
+    pub(crate) fn ser_submodules<'a, S: Serializer>(
+        module: &HashMap<CaoIdentifier<'a>, Module<'a>>,
+        s: S,
+    ) -> Result<S::Ok, S::Error> {
+        s.serialize_some(module)
+    }
+
+    pub(crate) fn ser_lane<S: Serializer>(
+        l: &HashMap<CaoIdentifier<'_>, Lane>,
+        s: S,
+    ) -> Result<S::Ok, S::Error> {
+        s.serialize_some(l)
+    }
 
     pub(crate) fn nullable_submodules<'de, 'a: 'de, D: Deserializer<'de>>(
         deserializer: D,
